@@ -4,6 +4,7 @@
 #'
 #' @param vec a continuous numerical variable
 #' @param n number of classes required (n = 7 is default)
+#' @param diglab number of digits (n = 2 is default)
 #'
 #' @return Vector with clustering
 #'
@@ -19,9 +20,9 @@
 #' doi: 10.1080/01621459.1958.10501479.
 #'
 #' @export fisher
-fisher <- function(vec, n = 7){
+fisher <- function(vec, n = 7, diglab = 2){
   cluster <- classIntervals(vec, n = n, style = 'fisher', intervalClosure = 'right')[[2]]
-  cut(vec, breaks = cluster, include.lowest = TRUE, dig.lab = 2)
+  cut(vec, breaks = cluster, include.lowest = TRUE, dig.lab = diglab)
 }
 
 
